@@ -24,10 +24,10 @@ impl Agent for SendmailMailer {}
 
 impl Handler<SendMail> for SendmailMailer {
     fn handle(&mut self, message: SendMail, cx: Context<Self, SendMail>) {
-        let mail = message.into_lettre_email(&self.from_address, &self.from_name);
+        let mail = message.into_lettre_message(&self.from_address, &self.from_name);
 
         let send_timer = metrics::AUTH_EMAIL_SEND_DURATION.start_timer();
-        let res = self.transport.send(mail);
+        let res = self.transport.send(&mail);
         send_timer.observe_duration();
 
         match res {
