@@ -1,11 +1,9 @@
 use crate::email_address::EmailAddress;
 use crate::utils::agent::*;
 use crate::{agents::*, metrics};
-use lettre::{
-    smtp::authentication::Credentials, ClientSecurity, ClientTlsParameters, SmtpClient,
-    SmtpTransport, Transport,
-};
-use native_tls::TlsConnector;
+use lettre::transport::smtp::authentication::Credentials;
+use lettre::transport::smtp::client::{Tls, TlsParameters};
+use lettre::{SmtpTransport, Transport};
 
 /// Mailer agent that uses `lettre` and SMTP.
 pub struct SmtpMailer {
@@ -24,24 +22,27 @@ impl SmtpMailer {
         // Extract domain, and build an address with a default port.
         // Split the same way `to_socket_addrs` does.
         let parts = server.rsplitn(2, ':').collect::<Vec<_>>();
-        let (domain, addr) = if parts.len() == 2 {
-            (parts[1].to_owned(), server.to_owned())
+        let (domain, port) = if parts.len() == 2 {
+            (
+                parts[1].to_owned(),
+                parts[0].parse().expect("Invalid SMTP port"),
+            )
         } else {
-            (parts[0].to_owned(), format!("{}:25", server))
+            (parts[0].to_owned(), 25)
         };
 
         // TODO: Configurable security.
-        let tls_connector = TlsConnector::new().expect("Could not initialize TLS for SMTP client");
-        let security =
-            ClientSecurity::Opportunistic(ClientTlsParameters::new(domain, tls_connector));
-        let mut client =
-            SmtpClient::new(&addr, security).expect("Could not create the SMTP client");
+        let tls_parameters =
+            TlsParameters::new(domain.clone()).expect("Could not initialize TLS for SMTP client");
+        let mut builder = SmtpTransport::builder_dangerous(&domain)
+            .port(port)
+            .tls(Tls::Opportunistic(tls_parameters));
         if let Some((username, password)) = credentials {
-            client = client.credentials(Credentials::new(username, password));
+            builder = builder.credentials(Credentials::new(username, password));
         }
 
         SmtpMailer {
-            transport: client.transport(),
+            transport: builder.build(),
             from_address,
             from_name,
         }
@@ -52,10 +53,10 @@ impl Agent for SmtpMailer {}
 
 impl Handler<SendMail> for SmtpMailer {
     fn handle(&mut self, message: SendMail, cx: Context<Self, SendMail>) {
-        let mail = message.into_lettre_email(&self.from_address, &self.from_name);
+        let mail = message.into_lettre_message(&self.from_address, &self.from_name);
 
         let send_timer = metrics::AUTH_EMAIL_SEND_DURATION.start_timer();
-        let res = self.transport.send(mail);
+        let res = self.transport.send(&mail);
         send_timer.observe_duration();
 
         match res {
@@ -65,7 +66,7 @@ impl Handler<SendMail> for SmtpMailer {
                 } else {
                     log::error!(
                         "SMTP server rejected a mail: {} {}",
-                        result.code,
+                        result.code(),
                         result.first_line().unwrap_or("")
                     );
                     cx.reply(false);
