@@ -82,13 +82,14 @@ impl RedisStore {
         }
         let id = rng.generate_async(16).await.into();
         let info = url.as_str().into_connection_info()?;
+        let addr = info.addr.clone();
         let pubsub = pubsub::connect(&info).await?;
         let conn = RedisClient::open(info)?
             .get_multiplexed_tokio_connection()
             .await?;
         let locking = locking::LockClient::new(conn.clone(), pubsub.clone(), rng);
 
-        log::warn!("Storing sessions and keys in Redis at {}", url);
+        log::warn!("Storing sessions and keys in Redis at {}", addr);
         log::warn!("Please always double check this Redis and the connection to it are secure!");
         log::warn!("(This warning can't be fixed; it's a friendly reminder.)");
 
