@@ -90,6 +90,7 @@ pub struct Config {
 /// Parameters for `StoreConfig::spawn_store`.
 struct StoreParams {
     session_ttl: Duration,
+    auth_code_ttl: Duration,
     cache_ttl: Duration,
     limit_configs: Vec<LimitConfig>,
     fetcher: Addr<FetchAgent>,
@@ -144,6 +145,7 @@ impl StoreConfig {
                 let store = agents::RedisStore::new(
                     redis_url,
                     params.session_ttl,
+                    params.auth_code_ttl,
                     params.cache_ttl,
                     params.limit_configs,
                     params.fetcher,
@@ -158,6 +160,7 @@ impl StoreConfig {
                 let store = agents::RusqliteStore::new(
                     sqlite_db,
                     params.session_ttl,
+                    params.auth_code_ttl,
                     params.cache_ttl,
                     params.limit_configs,
                     params.fetcher,
@@ -169,6 +172,7 @@ impl StoreConfig {
             StoreConfig::Memory => {
                 let store = agents::MemoryStore::new(
                     params.session_ttl,
+                    params.auth_code_ttl,
                     params.cache_ttl,
                     params.limit_configs,
                     params.fetcher,
@@ -347,6 +351,7 @@ pub struct ConfigBuilder {
     pub keys_ttl: Duration,
     pub token_ttl: Duration,
     pub session_ttl: Duration,
+    pub auth_code_ttl: Duration,
     pub cache_ttl: Duration,
 
     pub keyfiles: Vec<PathBuf>,
@@ -399,6 +404,7 @@ impl ConfigBuilder {
             keys_ttl: Duration::from_secs(86_400),
             token_ttl: Duration::from_secs(600),
             session_ttl: Duration::from_secs(900),
+            auth_code_ttl: Duration::from_secs(600),
             cache_ttl: Duration::from_secs(3600),
 
             keyfiles: Vec::new(),
@@ -489,7 +495,12 @@ impl ConfigBuilder {
         self
     }
 
+    pub fn is_keyed_manually(&self) -> bool {
+        !self.keyfiles.is_empty() || self.keytext.is_some()
+    }
+
     pub async fn done(mut self) -> Result<Config, ConfigError> {
+        let is_keyed_manually = self.is_keyed_manually();
         let store_config =
             StoreConfig::from_options(self.redis_url, self.sqlite_db, self.memory_storage)?;
         let mailer_config = MailerConfig::from_options(
@@ -515,36 +526,36 @@ impl ConfigBuilder {
         let store = store_config
             .spawn_store(StoreParams {
                 session_ttl: self.session_ttl,
+                auth_code_ttl: self.auth_code_ttl,
                 cache_ttl: self.cache_ttl,
                 limit_configs: self.limits,
                 fetcher: fetcher.clone(),
                 rng: rng.clone(),
             })
             .await;
-        let key_manager: Box<dyn KeyManagerSender> =
-            if !self.keyfiles.is_empty() || self.keytext.is_some() {
-                let key_manager = ManualKeys::new(
-                    &self.keyfiles,
-                    self.keytext,
-                    &self.signing_algs,
-                    rng.clone(),
-                )?;
-                Box::new(spawn_agent(key_manager).await)
-            } else {
-                if self.signing_algs.contains(&SigningAlgorithm::Rs256)
-                    && self.generate_rsa_command.is_empty()
-                {
-                    return Err("generate_rsa_command is required for rotating RSA keys".into());
-                }
-                let key_manager = RotatingKeys::new(
-                    store.clone(),
-                    self.keys_ttl,
-                    &self.signing_algs,
-                    self.generate_rsa_command,
-                    rng.clone(),
-                );
-                Box::new(spawn_agent(key_manager).await)
-            };
+        let key_manager: Box<dyn KeyManagerSender> = if is_keyed_manually {
+            let key_manager = ManualKeys::new(
+                &self.keyfiles,
+                self.keytext,
+                &self.signing_algs,
+                rng.clone(),
+            )?;
+            Box::new(spawn_agent(key_manager).await)
+        } else {
+            if self.signing_algs.contains(&SigningAlgorithm::Rs256)
+                && self.generate_rsa_command.is_empty()
+            {
+                return Err("generate_rsa_command is required for rotating RSA keys".into());
+            }
+            let key_manager = RotatingKeys::new(
+                store.clone(),
+                self.keys_ttl,
+                &self.signing_algs,
+                self.generate_rsa_command,
+                rng.clone(),
+            );
+            Box::new(spawn_agent(key_manager).await)
+        };
         let mailer = mailer_config
             .spawn_mailer(MailerParams {
                 fetcher,
@@ -616,6 +627,7 @@ impl ConfigBuilder {
         let store = store_config
             .spawn_store(StoreParams {
                 session_ttl: self.session_ttl,
+                auth_code_ttl: self.auth_code_ttl,
                 cache_ttl: self.cache_ttl,
                 limit_configs: self.limits,
                 fetcher,
